import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range([80, 50]);

export const fruitBowl = (selection, props) => {
  const { fruits, height } = props;
  
  const bowl = selection.selectAll('rect')
    .data([null])
    .enter().append('rect')
      .attr('y', 110)
      .attr('width', 930)
      .attr('height', 300)
      .attr('rx', 300 / 2 - 20)
    .transition().duration(8000)
      .attr('width', 570); 
  
  const groups = selection.selectAll('g')
    .data(fruits, d=>d.id);
  
  const groupsEnter = groups.enter()
    .append('g')
      .attr('transform', (d, i) => 
            `translate(${i * 180 + 100},${height / 2})`);
       
  groupsEnter
    .merge(groups)
      .transition().duration(1000)
        .attr('transform', (d, i) =>
          `translate(${i * 180 + 100},${height / 2})`
      );
      

  const groupsExit = groups.exit();
    
  groupsExit
    .select('circle')
      .transition().duration(100)
        .attr('r', 0)
  
  groupsExit
    .select('text')
      .transition().duration(100)
        .attr('opacity', 0); 
  
  groupsEnter.append('circle')
    .attr('r', 0)
    .merge(groups.select('circle'))
      .attr('fill', d => colorScale(d.type))
    .transition().duration(1000)
      .attr('r', d => radiusScale(d.type));
  
  groupsEnter.append('text')
    .attr('opacity', 0.0)
    .merge(groups.select('text'))
      .text(d => d.type)
      .attr('y', 120)
    .transition().duration(1000)
      .attr('opacity', 1.0); 
}